@@ -165,16 +165,6 @@ var __setColumnVis = function ( settings, column, vis ) {
 
 	// Common actions
 	col.bVisible = vis;
-	_fnDrawHead( settings, settings.aoHeader );
-	_fnDrawHead( settings, settings.aoFooter );
-
-	// Update colspan for no records display. Child rows and extensions will use their own
-	// listeners to do this - only need to update the empty table item here
-	if ( ! settings.aiDisplay.length ) {
-		$(settings.nTBody).find('td[colspan]').attr('colspan', _fnVisbleColumns(settings));
-	}
-
-	_fnSaveState( settings );
 };
 
 
@@ -238,6 +228,7 @@ _api_registerPlural( 'columns().nodes()', 'column().nodes()', function () {
 } );
 
 _api_registerPlural( 'columns().visible()', 'column().visible()', function ( vis, calc ) {
+	var that = this;
 	var ret = this.iterator( 'column', function ( settings, column ) {
 		if ( vis === undefined ) {
 			return settings.aoColumns[ column ].bVisible;
@@ -247,14 +238,28 @@ _api_registerPlural( 'columns().visible()', 'column().visible()', function ( vis
 
 	// Group the column visibility changes
 	if ( vis !== undefined ) {
-		// Second loop once the first is done for events
-		this.iterator( 'column', function ( settings, column ) {
-			_fnCallbackFire( settings, null, 'column-visibility', [settings, column, vis, calc] );
-		} );
+		this.iterator( 'table', function ( settings ) {
+			// Redraw the header after changes
+			_fnDrawHead( settings, settings.aoHeader );
+			_fnDrawHead( settings, settings.aoFooter );
+	
+			// Update colspan for no records display. Child rows and extensions will use their own
+			// listeners to do this - only need to update the empty table item here
+			if ( ! settings.aiDisplay.length ) {
+				$(settings.nTBody).find('td[colspan]').attr('colspan', _fnVisbleColumns(settings));
+			}
+	
+			_fnSaveState( settings );
 
-		if ( calc === undefined || calc ) {
-			this.columns.adjust();
-		}
+			// Second loop once the first is done for events
+			that.iterator( 'column', function ( settings, column ) {
+				_fnCallbackFire( settings, null, 'column-visibility', [settings, column, vis, calc] );
+			} );
+
+			if ( calc === undefined || calc ) {
+				that.columns.adjust();
+			}
+		});
 	}
 
 	return ret;
