@@ -99,7 +99,7 @@ _fnLanguageCompat( oInit.oLanguage );
 // If the length menu is given, but the init display length is not, use the length menu
 if ( oInit.aLengthMenu && ! oInit.iDisplayLength )
 {
-	oInit.iDisplayLength = $.isArray( oInit.aLengthMenu[0] ) ?
+	oInit.iDisplayLength = Array.isArray( oInit.aLengthMenu[0] ) ?
 		oInit.aLengthMenu[0][0] : oInit.aLengthMenu[0];
 }
 
@@ -190,7 +190,7 @@ if ( oSettings.iInitDisplayStart === undefined )
 if ( oInit.iDeferLoading !== null )
 {
 	oSettings.bDeferLoading = true;
-	var tmp = $.isArray( oInit.iDeferLoading );
+	var tmp = Array.isArray( oInit.iDeferLoading );
 	oSettings._iRecordsDisplay = tmp ? oInit.iDeferLoading[0] : oInit.iDeferLoading;
 	oSettings._iRecordsTotal = tmp ? oInit.iDeferLoading[1] : oInit.iDeferLoading;
 }
@@ -209,9 +209,11 @@ if ( oLanguage.sUrl )
 		dataType: 'json',
 		url: oLanguage.sUrl,
 		success: function ( json ) {
-			_fnLanguageCompat( json );
 			_fnCamelToHungarian( defaults.oLanguage, json );
+			_fnLanguageCompat( json );
 			$.extend( true, oLanguage, json );
+
+			_fnCallbackFire( oSettings, null, 'i18n', [oSettings]);
 			_fnInitialise( oSettings );
 		},
 		error: function () {
@@ -221,6 +223,9 @@ if ( oLanguage.sUrl )
 	} );
 	bInitHandedOff = true;
 }
+else {
+	_fnCallbackFire( oSettings, null, 'i18n', [oSettings]);
+}
 
 /*
  * Stripes
@@ -372,7 +377,7 @@ var loadedInit = function () {
 
 	var tbody = $this.children('tbody');
 	if ( tbody.length === 0 ) {
-		tbody = $('<tbody/>').appendTo($this);
+		tbody = $('<tbody/>').insertAfter(thead);
 	}
 	oSettings.nTBody = tbody[0];
 
@@ -420,10 +425,11 @@ var loadedInit = function () {
 };
 
 /* Must be done after everything which can be overridden by the state saving! */
+_fnCallbackReg( oSettings, 'aoDrawCallback', _fnSaveState, 'state_save' );
+
 if ( oInit.bStateSave )
 {
 	features.bStateSave = true;
-	_fnCallbackReg( oSettings, 'aoDrawCallback', _fnSaveState, 'state_save' );
 	_fnLoadState( oSettings, oInit, loadedInit );
 }
 else {
