@@ -86,7 +86,7 @@ $.extend( true, DataTable.ext.renderer, {
 				for ( i=0, ien=buttons.length ; i<ien ; i++ ) {
 					button = buttons[i];
 
-					if ( $.isArray( button ) ) {
+					if ( Array.isArray( button ) ) {
 						var inner = $( '<'+(button.DT_el || 'div')+'/>' )
 							.appendTo( container );
 						attach( inner, button );
@@ -131,14 +131,14 @@ $.extend( true, DataTable.ext.renderer, {
 							case 'last':
 								btnDisplay = lang.sLast;
 
-								if ( page === pages-1 ) {
+								if ( pages === 0 || page === pages-1 ) {
 									tabIndex = -1;
 									btnClass += ' ' + disabledClass;
 								}
 								break;
 
 							default:
-								btnDisplay = button + 1;
+								btnDisplay = settings.fnFormatNumber( button + 1 );
 								btnClass = page === button ?
 									classes.sPageButtonActive : '';
 								break;
